////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// F A R M     -  Flair advanced rendering module
//
// Copyright European Organization for Nuclear Research( CERN )
// All rights reserved
//
// Authors: Christian.Theis@cern.ch
//			    Vasilis.Vlachoudis@cern.ch
//
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "bxdffresnelblendex.h"
#include "bxdffresnel.h"

CBxDFFresnelBlendEx::CBxDFFresnelBlendEx( CMicrofacetDistribution* pDist) : CBxDFFresnelBlend( pDist )
{
}

CBxDFFresnelBlendEx::~CBxDFFresnelBlendEx(void)
{
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////

double CBxDFFresnelBlendEx::Sample_f( const Ray& Out, Ray& In, float& Pdf, const Vector& Normal, const Material& RenderMat, Random& Sampler, BxDFType Type, const Color& LightColor /*= Color( 1.0, 1.0, 1.0 )*/, double Power /*= 1.0*/, float Shade /*= 1.0 */ )

// ATTENTION: By convention the direction of the outgoing ray is opposite to the one which is incoming!
//            (Out is pointing towards the face, wherease in is pointing away as we solve the transport
//             equation practically going reverse from out to in).
//
// NOTE: In contrast to CBxDFFresnel this model samples perfect specular reflection instead of a micro-facet
//       distribution
////////////////////////////////////////////////////////////////////////////////////////////////////////////
{
  UNUSED( Shade ); UNUSED( Power ); UNUSED( LightColor ); UNUSED( Type ); UNUSED( Sampler );

  Vector HalfVec(-Out.dir() + In.dir() );
  Vector R = (-2.0 * Out.dir() * Normal) * Normal + Out.dir(); // reflect incoming ray
  double  DotInHalf;


	In = Out;
	In.init();
	In.incDepth();	// to avoid infinite loops
	In.push( RaySegment( Out.hit( -SMALL3D4 ), R, Out.prevZone() ) );

  Pdf = 1.0;

  // scale reflection according to the Fresnel coefficients
  HalfVec.normalize();
  DotInHalf = In.dir().dot( HalfVec );

  return CFresnelHelpers::SchlickFresnel( 1.0 - RenderMat.specular(), DotInHalf );
}
// vim:ts=2
