////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// F A R M     -  Flair advanced rendering module
//
// Copyright European Organization for Nuclear Research( CERN )
// All rights reserved
//
// Authors: Christian.Theis@cern.ch
//			    Vasilis.Vlachoudis@cern.ch
//
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef MAT_BLINN_H
#define MAT_BLINN_H

#include "physmatinterface.h"
#include "bxdfbase.h"
#include "bxdffresnel.h"
#include "bxdfphong.h"
#include "bxdflambert.h"
#include "bxdfblinn.h"
#include "bxdfspecrefl.h"
#include "bxdfspectransmission.h"
#include "baseintegrator.h"

class CBxDFPhong;
class CFresnelPreDefDiel;
class CBxDFSpecReflection;
class CBxDFSpecTransmission;

class CMatBlinn : public CPhysMatInterface
{
public:
  CMatBlinn( CBaseIntegrator* pInt );
  virtual ~CMatBlinn(void);

	// f( Out, In) evaluates the BxDF for the in & outgoing pair of rays
	// Out = ray coming FROM the camera, In = ray going towards the light
	virtual double f( const Ray& Out, const Ray& In, const Vector& Normal, const Material& RenderMat, const Color& LightColor, double Power, float Shade = 1.0 );

	// By default only diffuse sampling is performed. This function needs to be overwritten by the actual physical materials that
	// have reflective and probably translucent components!
	virtual double Sample_f( const Ray& Out, Ray& In, float& Pdf, const Vector& Normal, const Material& RenderMat, Random& Sampler, CBxDFBase::BxDFType Type, const Color& LightColor = Color( 1.0, 1.0, 1.0 ), double Power = 1.0, float Shade = 1.0 );

protected:
  CBxDFLambert            m_BxDFDiffuse;
  CBxDFBlinn              m_BxDFSpecular;
  CBxDFSpecReflection*    m_pBxDFReflection;
  CBxDFSpecTransmission   m_BxDFTransmission;
  CFresnel*               m_pFresnel;
};


#endif
// vim:ts=2
