////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//
// F A R M     -  Flair advanced rendering module
//
// Copyright European Organization for Nuclear Research( CERN )
// All rights reserved
//
// Authors: Christian.Theis@cern.ch
//			    Vasilis.Vlachoudis@cern.ch
//
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#ifndef MAT_PLASTIC_H
#define MAT_PLASTIC_H

#include "physmatinterface.h"
#include "bxdfbase.h"
#include "baseintegrator.h"
#include "bxdffresnel.h"
#include "bxdfmicrofacet.h"
#include "bxdfphong.h"
#include "blinnmicrodist.h"
#include "bxdfspecrefl.h"
#include "bxdfspectransmission.h"

class CBxDFPhong;
class CBxDFMicrofacet;
class CFresnelPreDefDiel;
class CBlinnMicroDist;
class CBxDFSpecReflection;
class CBxDFSpecTransmission;

class CMatPlastic : public CPhysMatInterface
{
public:
  explicit CMatPlastic( CBaseIntegrator* pInt, const float cRoughness = 1.0 );
  virtual ~CMatPlastic(void);

	// f( Out, In) evaluates the BxDF for the in & outgoing pair of rays
	// Out = ray coming FROM the camera, In = ray going towards the light
	virtual double f( const Ray& Out, const Ray& In, const Vector& Normal, const Material& RenderMat, const Color& LightColor, double Power, float Shade = 1.0 );

	// By default only diffuse sampling is performed. This function needs to be overwritten by the actual physical materials that
	// have reflective and probably translucent components!
	virtual double Sample_f( const Ray& Out, Ray& In, float& Pdf, const Vector& Normal, const Material& RenderMat, Random& Sampler, CBxDFBase::BxDFType Type, const Color& LightColor = Color( 1.0, 1.0, 1.0 ), double Power = 1.0, float Shade = 1.0 );

protected:
  CBxDFPhong*             m_pBxDFDiffuse;
  CBxDFMicrofacet*        m_pBxDFSpecular;
  CFresnelPreDefDiel*     m_pFresnelDiel;
  CBlinnMicroDist*        m_pBlinnMicroDist;
  CBxDFSpecReflection*    m_pBxDFSpecReflection;
  CBxDFSpecTransmission*  m_pBxDFSpecTransmission;
};


#endif
// vim:ts=2
