/*
 * Copyright European Organization for Nuclear Research (CERN)
 * All rights reserved
 *
 * Author:	David.Sinuela.Pastor@cern.ch
 * Date:	Sep-2012
 *
 */

#include "svgexport.h"

#include <iomanip>

#include "os.h"

/* =============================== SVGExport =============================== */
SVGExport::SVGExport(const std::string& filename)
	: ExportBase(filename)
{
	if (_file)
		writeHeader();
} // SVGExport

SVGExport::~SVGExport(void)
{
	if (_file) {
		writeEOF();
		_file.close();
	}
} // ~SVGExport

/** attributes */
void SVGExport::attributes(dword color, float width, const char* layer)
{
	_file << " stroke=\"#" << std::hex << std::setw(6) << std::setfill('0') << color << "\"";
	_file << " stroke-width=\"" << width << "\"";
	_file << " fill=\"\"";
	_file << " class=\"layer" << layer << '\"';
} // attributes

/** line */
bool SVGExport::line(double x1, double y1, double x2, double y2, dword color, const char* layer)
{
	_file << "<line"
	      << " x1=\"" << x1 << '\"'
	      << " y1=\"" << y1 << '\"'
	      << " x2=\"" << x2 << '\"'
	      << " y2=\"" << y2 << '\"';
	attributes(color, 0.25, layer);
	_file << "/>" << std::endl;
	return true;
} // line

/** circle */
bool SVGExport::circle(double x, double y, double radius, dword color, const char* layer)
{
	_file << "<circle"
	      << " cx=\"" << x      << '\"'
	      << " cy=\"" << y      << '\"'
	      << " r=\""  << radius << '\"';
	attributes(color, 0.25, layer);
	_file << "/>" << std::endl;
	return true;
} // circle

/** arc */
bool SVGExport::arc(double, double, double, double, double, dword, const char*)
{
	return true;
} // arc

/** rectangle */
bool SVGExport::rectangle(double left, double bottom, double right, double top, dword color, const char* layer)
{
	_file << "<rect"
	      << " x=\"" << left            << '\"'
	      << " y=\"" << bottom          << '\"'
	      << " width=\""  << right-left << '\"'
	      << " height=\"" << top-bottom << '\"';
	attributes(color, 0.25, layer);
	_file << "/>" << std::endl;
	return true;
} // rectangle

/** writeHeader */
bool SVGExport::writeHeader()
{
	_file << "<svg xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\">" << std::endl;
	return true;
} // WriteHeader

/** WriteEOF */
bool SVGExport::writeEOF()
{
	_file <<  "</svg>" << std::endl;

	return true;
} // writeEOF
