/*
 * Copyright European Organization for Nuclear Research (CERN)
 * All rights reserved
 *
 * Please look at the supplied documentation for the user's
 * license
 *
 * Author:	Vasilis.Vlachoudis@cern.ch
 * Date:        19 Feb 2013
 */

#ifndef __NOX_H
#define __NOX_H

#include <vector>
#include <fstream>

#include "viewer/viewer.h"
#include "geometry/geometry.h"

class Token;
class Matrix4;

struct region_material_t {
	int	region_id;
	dword	color;
	int	alpha;
};

/** Nox Geometry/Viewer parser
 */
class NoxGeometry {
public:
	Geometry	geometry;
	GeometryKernel	kernel;
	GeometryViewer	viewer;
	std::vector<region_material_t> region_materials;
	bool		dump;

public:
	NoxGeometry(const char* filename=NULL);
	bool	load(const char* filename);
	void	cleanup();

private:
	bool	parse(std::ifstream& input);
	GBody*	parseBody(Token&);
	GRegion* parseRegion(Token&);
	//bool	parseRegionExpr(Token&, GRegion*)
	void	parseVoxel(Token&);
	void	assignRegionMaterials();
	static void parseMatrix(Token&, Matrix4&);
}; // class NoxGeometry
#endif
