/*
 * Copyright European Organization for Nuclear Research (CERN)
 * All rights reserved
 *
 * Author:	Vasilis.Vlachoudis@cern.ch
 */

#include "voxellayer.h"
#include "viewer.h"

/** draw */
void VoxelLayer::draw(Painter& painter)
{
	Point	r(0.0, 0.0, 0.0);
	dword* ptr = painter.data();
	int H = painter.height();	// save variables that might change
	int W = painter.width();	// during the scanning...

	for (int j=0; j<H; j++) {
		if (stop()) break;

		r.y = view().j2v(j);

		for (int i=0; i<W; i++, ptr++) {
			if (*ptr!=geometry.voxelColor && *ptr!=hashColor)
				continue;

			r.x = view().i2u(i);
			Point p = view().matrix() * r;

			bool ok;
			dword color = kernel.voxel.color(p, &ok);
			if (!ok) continue;
			// FIXME transparent color in voxels
			//if (color==COLOR_TRANSPARENT && show3D)
			//	color = geometry.transparentColor;

			if (*ptr == hashColor)
				*ptr = Color32::darker(color, level) | FLAG_VOXEL;
			else
				*ptr = color | FLAG_VOXEL;
		}
	}
#ifdef EXPERIMENTAL
	drawStructure(painter);
#endif
} // draw

#ifdef EXPERIMENTAL
/** drawStructure */
void VoxelLayer::drawStructure(Painter& )
{
	for (int i=0; i<geometry.voxel.nroi(); i++) {
		if (kernel.voxel.roiShow(i)) {
		}
	}
} // drawStructure
#endif
